#!/usr/bin/env python

try:
    import json
except ImportError:
    import simplejson as json

import requests
import sys
from pagerduty.version import *

__version__ = VERSION

class PagerDutyException(Exception):
    def __init__(self, status, message, errors=None):
        super(PagerDutyException, self).__init__(message)
        self.msg = message
        self.status = status
        self.errors = errors
    
    def __repr__(self):
        return "%s(%r, %r, %r)" % (self.__class__.__name__, self.status, self.msg, self.errors)
    
    def __str__(self):
        txt = "%s: %s" % (self.status, self.msg)
        if self.errors:
            txt += "\n" + "\n".join("* %s" % x for x in self.errors)
        return txt

class PagerDuty(object):
    def __init__(self, service_key, https=True, timeout=15):
        self.service_key = service_key
        self.api_endpoint = ("http", "https")[https] + "://events.pagerduty.com/generic/2010-04-15/create_event.json"
        self.timeout = timeout
    
    def trigger(self, description, incident_key=None, details=None):
        description = bytes(description, 'UTF-8')
        return self._request("trigger", description=description, incident_key=incident_key, details=details)
    
    def acknowledge(self, incident_key, description=None, details=None):
        return self._request("acknowledge", description=description, incident_key=incident_key, details=details)
    
    def resolve(self, incident_key, description=None, details=None):
        return self._request("resolve", description=description, incident_key=incident_key, details=details)
    
    def _request(self, event_type, **kwargs):
        event = {
            "service_key": self.service_key,
            "event_type": event_type,
        }
        for k, v in list(kwargs.items()):
            if v is not None:
                print("Key {0} has value {1}".format(k,v), file=sys.stderr)
                event[k] = v

        print("EVENT: {0}".format(event), file=sys.stderr)
        #encoded_event = json.dumps(str(event))
        print("ENCODED_ENVT: {0}".format(encoded_event), file=sys.stderr)
        try:
            res = requests.post(self.api_endpoint, data=event)
        except Exception as e:
            print("Exception: {0}".format(e), file=sys.stderr)
        result = json.loads(res.text)
        print("STATUS {0}".format(res.status_code), file=sys.stderr)
        if res.status_code != requests.codes.ok:
            raise PagerDutyException(res.status_code, res.text, result['errors'])
        
        # if result['warnings]: ...
        
        return result.get('incident_key')



#!/usr/bin/env python

import sys
from optparse import OptionParser

from pagerduty import PagerDuty, PagerDutyException

def build_opt_parser():
    parser = OptionParser(usage="Usage: %prog [options] <trigger/acknowledge/resolve>")
    parser.add_option("-d", "--details", dest="details", help="Optional JSON details")
    parser.add_option("", "--description", dest="description", help="Description")
    parser.add_option("-i", "--incident", dest="incident_key", help="unique incident key")
    parser.add_option("-k", "--key", dest="service_key", help="service key")
    return parser

def main():
    parser = build_opt_parser()
    (options, args) = parser.parse_args()
    if not args:
        parser.error("must specify an action: trigger, acknowledge, or resolve")
    if not options.service_key:
        parser.error("service key is required")
    
    action = args[0]
    
    description = options.description
    if action == "trigger":
        if description in (None, "-"):
            description = sys.stdin.read()
        if not description:
            sys.stderr.write("Action trigger requires a description\n")
            sys.exit(1)
    elif action in ("acknowledge", "resolve"):
        if not options.incident_key:
            sys.stderr.write("Action %s requires an incident key\n" % action)
            sys.exit(1)
        if description == "-":
            description = sys.stdin.read()
    
    pg = PagerDuty(options.service_key)
    try:
        ik = getattr(pg, action)(
            description = description,
            incident_key = options.incident_key,
            details = options.details,
        )
    except PagerDutyException as exc:
        sys.stderr.write(str(exc)+"\n")
        sys.exit(2)
    
    if ik:
        print(ik)

if __name__ == "__main__":
    main()



#!/usr/bin/env python

from setuptools import setup, find_packages

import os
exec(compile(open(os.path.join('pagerduty', 'version.py')).read(), os.path.join('pagerduty', 'version.py'), 'exec'))

try:
    long_description = open("README.md").read()
except IOError:
    long_description = ""

setup(
    name = 'python3-pagerduty',
    version = VERSION,
    description = 'Library for the PagerDuty service API',
    long_description = long_description,
    author = 'Samuel Stauffer',
    author_email = 'samuel@playhaven.com',
    url = 'http://github.com/samuel/python-pagerduty',
    packages = find_packages(),
    install_requires=open('requirements.txt', 'r').readlines(),
    license = "BSD",
    entry_points = {
        "console_scripts": [
            "pagerduty = pagerduty.command:main",
        ],
    },
    classifiers = [
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'License :: OSI Approved :: BSD License',
        'Topic :: Software Development',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)
